@@ -46,6 +46,10 @@
 #' considered to be the edge data.
 #' @param blocked_CV default is FALSE, if changed to TRUE, blocked cross-validation
 #' will be used to compare regression methods.
+#' @param MLR_stepwise if set to TRUE, stepwise selection of predictors will be used
+#' for the MLR method
+#' @param stepwise_direction the mode of stepwise search, can be one of "both",
+#' "backward", or "forward", with a default of "backward".
 #' @param PCA_transformation if set to TRUE, all independent variables will be
 #' transformed using PCA transformation.
 #' @param log_preprocess if set to TRUE, variables will be transformed with
@@ -93,7 +97,7 @@
 #'\tabular{rll}{
 #'  1 \tab $mean_std   \tab data frame with calculated metrics for the selected regression methods. For each regression method and each calculated metric, mean and standard deviation are given\cr
 #'  2 \tab $ranks \tab data frame with ranks of calculated metrics: mean rank and  share of rank_1 are given \cr
-#'  3 \tab $edge_results   \tab data frame with calculated performance metrics for the central-edge test. The central part of the data represents the calibration data, while the edge data, i.e. extreme values, represent the edge data. Different regression models are calibrated using the central data and validated for the edge (extreme) data. This test is particularly important to assess the performance of models for the prediction of the extreme data. The share of the edge (extreme) data is defined with the edge_share argument \cr
+#'  3 \tab $edge_results   \tab data frame with calculated performance metrics for the central-edge test. The central part of the data represents the calibration data, while the edge data, i.e. extreme values, represent the test/validation data. Different regression models are calibrated using the central data and validated for the edge (extreme) data. This test is particularly important to assess the performance of models for the predictions of the extreme data. The share of the edge (extreme) data is defined with the edge_share argument \cr
 #'  4 \tab $bias_cal   \tab ggplot object of mean bias for calibration data \cr
 #'  5 \tab $bias_val    \tab ggplot object of mean bias for validation data \cr
 #'  6 \tab $transfer_functions   \tab ggplot or plotly object with transfer functions of methods \cr
@@ -170,7 +174,7 @@
 #' experiment_3 <- compare_methods(formula = MVA ~ .,
 #' dataset = example_dataset_1, k = 2, repeats = 5,
 #' methods = c("MLR", "BRNN", "MT", "BMT"),
-#' optimize = TRUE)
+#' optimize = TRUE, MLR_stepwise = TRUE)
 #' experiment_3$mean_std
 #' experiment_3$ranks
 #' experiment_3$bias_val
@@ -183,7 +187,8 @@
 #' data(dataset_TRW)
 #' comparison_TRW <- compare_methods(formula = T_Jun_Jul ~ TRW, dataset = dataset_TRW,
 #' k = 3, repeats = 10, optimize = TRUE, methods = c("MLR", "MT", "BMT", "BRNN"),
-#' seed_factor = 5, dataset_complete = dataset_TRW_complete)
+#' seed_factor = 5, dataset_complete = dataset_TRW_complete, MLR_stepwise = TRUE,
+#' stepwise_direction = "backward")
 #' comparison_TRW$mean_std
 #' comparison_TRW$bias_val
 #' comparison_TRW$transfer_functions + xlab(expression(paste('TRW'))) +
@@ -204,6 +209,7 @@ compare_methods <- function(formula, dataset, k = 10, repeats = 2,
                             eigenvalues_threshold = 1, N_components = 2,
                             round_bias_cal = 15, round_bias_val = 4,
                             n_bins = 30, edge_share = 0.10,
+                            MLR_stepwise = FALSE, stepwise_direction = "backward",
                             methods = c("MLR", "BRNN", "MT", "BMT", "RF"),
                             tuning_metric = "RMSE",
                             BRNN_neurons_vector = c(1, 2, 3),
@@ -362,7 +368,8 @@ if (optimize == TRUE & blocked_CV == FALSE){
         train <- dataset[-testIndexes, ]
 
         #MLR MODEL
-        capture.output(model_temp <- brnn(formula, data = train, neurons = neurons, verbose = FALSE))
+        capture.output(model_temp <- brnn(formula, data = train, neurons = neurons, verbose = FALSE,
+                                          tol = 1e-6))
         test_observed <- test[, DepIndex]
         test_predicted <- predict(model_temp, test)
 
@@ -1099,17 +1106,31 @@ for (j in 1:k){
   train <- dataset[-testIndexes, ]
 
   #MLR MODEL
-  MLR <- lm(formula, data = train)
-  train_predicted <- predict(MLR, train)
-  test_predicted <- predict(MLR, test)
-  train_observed <- train[, DepIndex]
-  test_observed <- test[, DepIndex]
-  calculations <- calculate_metrics(train_predicted, test_predicted,
-                                         train_observed, test_observed, digits = 15)
-  list_MLR[[b]] <- calculations
+  if (MLR_stepwise == FALSE) {
+    MLR <- lm(formula, data = train)
+    train_predicted <- predict(MLR, train)
+    test_predicted <- predict(MLR, test)
+    train_observed <- train[, DepIndex]
+    test_observed <- test[, DepIndex]
+    calculations <- calculate_metrics(train_predicted, test_predicted,
+                                      train_observed, test_observed, digits = 15)
+    list_MLR[[b]] <- calculations
+
+  } else {
+    capture.output(MLR <- step(lm(formula = formula, data = train), direction = stepwise_direction))
+    train_predicted <- predict(MLR, train)
+    test_predicted <- predict(MLR, test)
+    train_observed <- train[, DepIndex]
+    test_observed <- test[, DepIndex]
+    calculations <- calculate_metrics(train_predicted, test_predicted,
+                                      train_observed, test_observed, digits = 15)
+    list_MLR[[b]] <- calculations
+  }
+
 
   #BRNN Model
-  capture.output(BRNN <- brnn(formula, data = train, neurons = BRNN_neurons, verbose = FALSE))
+  capture.output(BRNN <- brnn(formula, data = train, neurons = BRNN_neurons, verbose = FALSE,
+                              tol = 1e-6))
   train_predicted <- predict(BRNN, train)
   test_predicted <- predict(BRNN, test)
   calculations <- calculate_metrics(train_predicted, test_predicted,
@@ -1193,17 +1214,30 @@ if (blocked_CV == TRUE){
     train <- dataset[-testIndexes, ]
 
     #MLR MODEL
-    MLR <- lm(formula, data = train)
-    train_predicted <- predict(MLR, train)
-    test_predicted <- predict(MLR, test)
-    train_observed <- train[, DepIndex]
-    test_observed <- test[, DepIndex]
-    calculations <- calculate_metrics(train_predicted, test_predicted,
-                                       train_observed, test_observed, digits = 15)
-    list_MLR[[b]] <- calculations
+    if (MLR_stepwise == FALSE) {
+      MLR <- lm(formula, data = train)
+      train_predicted <- predict(MLR, train)
+      test_predicted <- predict(MLR, test)
+      train_observed <- train[, DepIndex]
+      test_observed <- test[, DepIndex]
+      calculations <- calculate_metrics(train_predicted, test_predicted,
+                                        train_observed, test_observed, digits = 15)
+      list_MLR[[b]] <- calculations
+
+    } else {
+      capture.output(MLR <- step(lm(formula = formula, data = train), direction = stepwise_direction))
+      train_predicted <- predict(MLR, train)
+      test_predicted <- predict(MLR, test)
+      train_observed <- train[, DepIndex]
+      test_observed <- test[, DepIndex]
+      calculations <- calculate_metrics(train_predicted, test_predicted,
+                                        train_observed, test_observed, digits = 15)
+      list_MLR[[b]] <- calculations
+    }
 
     #BRNN Model
-    capture.output(BRNN <- brnn(formula, data = train, neurons = BRNN_neurons, verbose = FALSE))
+    capture.output(BRNN <- brnn(formula, data = train, neurons = BRNN_neurons, verbose = FALSE,
+                                tol = 1e-6))
     train_predicted <- predict(BRNN, train)
     test_predicted <- predict(BRNN, test)
     calculations <- calculate_metrics(train_predicted, test_predicted,
@@ -1259,8 +1293,8 @@ if (blocked_CV == TRUE){
 
 listVec <- lapply(list_MLR, c, recursive = TRUE)
 m <- do.call(cbind, listVec)
-averages <- apply(m, 1, mean)
-std <- apply(m, 1, sd)
+averages <- apply(m, 1, mean, na.rm = TRUE)
+std <- apply(m, 1, sd, na.rm = TRUE)
 m <- cbind(m, averages, std)
 df_MLR <- data.frame(m)
 df_MLR_bias <- df_MLR[c(13, 14), c(1: position)]
@@ -1272,8 +1306,8 @@ rownames(df_MLR_avg) <- c("r_cal", "r_val", "RMSE_cal", "RMSE_val", "RSSE_cal",
 
 listVec <- lapply(list_BRNN, c, recursive = TRUE)
 m <- do.call(cbind, listVec)
-averages <- apply(m, 1, mean)
-std <- apply(m, 1, sd)
+averages <- apply(m, 1, mean, na.rm = TRUE)
+std <- apply(m, 1, sd, na.rm = TRUE)
 m <- cbind(m, averages, std)
 df_BRNN <- data.frame(m)
 df_BRNN_bias <- df_BRNN[c(13, 14), c(1: position)]
@@ -1285,8 +1319,8 @@ rownames(df_BRNN_avg) <- c("r_cal", "r_val", "RMSE_cal", "RMSE_val", "RSSE_cal",
 
 listVec <- lapply(list_MT, c, recursive = TRUE)
 m <- do.call(cbind, listVec)
-averages <- apply(m, 1, mean)
-std <- apply(m, 1, sd)
+averages <- apply(m, 1, mean, na.rm = TRUE)
+std <- apply(m, 1, sd, na.rm = TRUE)
 m <- cbind(m, averages, std)
 df_MT <- data.frame(m)
 df_MT_bias <- df_MT[c(13, 14), c(1: position)]
@@ -1298,8 +1332,8 @@ rownames(df_MT_avg) <- c("r_cal", "r_val", "RMSE_cal", "RMSE_val", "RSSE_cal",
 
 listVec <- lapply(list_BMT, c, recursive = TRUE)
 m <- do.call(cbind, listVec)
-averages <- apply(m, 1, mean)
-std <- apply(m, 1, sd)
+averages <- apply(m, 1, mean, na.rm = TRUE)
+std <- apply(m, 1, sd, na.rm = TRUE)
 m <- cbind(m, averages, std)
 df_BMT <- data.frame(m)
 df_BMT_bias <- df_BMT[c(13, 14), c(1: position)]
@@ -1311,8 +1345,8 @@ rownames(df_BMT_avg) <- c("r_cal", "r_val", "RMSE_cal", "RMSE_val", "RSSE_cal",
 
 listVec <- lapply(list_RF, c, recursive = TRUE)
 m <- do.call(cbind, listVec)
-averages <- apply(m, 1, mean)
-std <- apply(m, 1, sd)
+averages <- apply(m, 1, mean, na.rm = TRUE)
+std <- apply(m, 1, sd, na.rm = TRUE)
 m <- cbind(m, averages, std)
 df_RF <- data.frame(m)
 df_RF_bias <- df_RF[c(13, 14), c(1: position)]
